@@ -47,18 +47,22 @@ pub trait CsrfDepotExt {
 }
 
 impl CsrfDepotExt for Depot {
+    #[inline]
     fn csrf_token(&self) -> Option<&str> {
         self.get::<CsrfData>(DATA_KEY).map(|d| &*d.token)
     }
 
+    #[inline]
     fn csrf_header_name(&self) -> Option<&str> {
         self.get::<CsrfData>(DATA_KEY).map(|d| d.header_name.as_str())
     }
 
+    #[inline]
     fn csrf_query_param(&self) -> Option<&str> {
         self.get::<CsrfData>(DATA_KEY).map(|d| &*d.query_param)
     }
 
+    #[inline]
     fn csrf_field_name(&self) -> Option<&str> {
         self.get::<CsrfData>(DATA_KEY).map(|d| &*d.field_name)
     }
@@ -78,6 +82,7 @@ pub struct CsrfHandler {
 }
 
 impl fmt::Debug for CsrfHandler {
+    #[inline]
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
         f.debug_struct("CsrfHandler")
             .field("cookie_path", &self.cookie_path)
@@ -106,6 +111,7 @@ impl CsrfHandler {
     /// - query param: `csrf-token`
     /// - form field: `csrf-token`
     /// - protected methods: `[POST, PUT, PATCH, DELETE]`
+    #[inline]
     pub fn new(secret: &[u8]) -> Self {
         let mut key = [0u8; 32];
         derive_key(secret, &mut key);
@@ -131,6 +137,7 @@ impl CsrfHandler {
     /// valid.
     ///
     /// The default for this value is one day.
+    #[inline]
     pub fn with_ttl(mut self, ttl: Duration) -> Self {
         self.ttl = ttl;
         self
@@ -140,6 +147,7 @@ impl CsrfHandler {
     /// for the CSRF token.
     ///
     /// Defaults to "x-csrf-token".
+    #[inline]
     pub fn with_header_name(mut self, header_name: HeaderName) -> Self {
         self.header_name = header_name;
         self
@@ -149,6 +157,7 @@ impl CsrfHandler {
     /// look for the CSRF token.
     ///
     /// Defaults to "csrf-token".
+    #[inline]
     pub fn with_query_param(mut self, query_param: impl AsRef<str>) -> Self {
         self.query_param = query_param.as_ref().into();
         self
@@ -158,20 +167,23 @@ impl CsrfHandler {
     /// for the CSRF token.
     ///
     /// Defaults to "csrf-token".
+    #[inline]
     pub fn with_form_field(mut self, form_field: impl AsRef<str>) -> Self {
         self.form_field = form_field.as_ref().into();
         self
     }
 
     /// Sets the list of methods that will be protected by this
-    /// middleware
+    /// middleware.
     ///
     /// Defaults to `[POST, PUT, PATCH, DELETE]`
+    #[inline]
     pub fn with_protected_methods(mut self, methods: &[Method]) -> Self {
         self.protected_methods = methods.iter().cloned().collect();
         self
     }
 
+    #[inline]
     fn build_cookie(&self, secure: bool, cookie_value: String) -> Cookie<'static> {
         let expires = cookie::time::OffsetDateTime::now_utc() + self.ttl;
         let mut cookie = Cookie::build(self.cookie_name.clone(), cookie_value)
@@ -189,6 +201,7 @@ impl CsrfHandler {
         cookie
     }
 
+    #[inline]
     fn generate_token(&self, existing_cookie: Option<&UnencryptedCsrfCookie>) -> (CsrfToken, CsrfCookie) {
         let existing_cookie_bytes = existing_cookie.and_then(|c| {
             let c = c.value();
@@ -206,6 +219,7 @@ impl CsrfHandler {
             .expect("couldn't generate token/cookie pair")
     }
 
+    #[inline]
     fn find_csrf_cookie(&self, req: &Request) -> Option<UnencryptedCsrfCookie> {
         req.cookie(&self.cookie_name)
             .and_then(|c| match base64::decode(c.value().as_bytes()) {
@@ -224,6 +238,7 @@ impl CsrfHandler {
             })
     }
 
+    #[inline]
     async fn find_csrf_token(&self, req: &mut Request) -> Result<UnencryptedCsrfToken, Error> {
         // A bit of a strange flow here (with an early exit as well),
         // because we do not want to do the expensive parsing (form,
@@ -246,6 +261,7 @@ impl CsrfHandler {
         self.protect.parse_token(&csrf_token).map_err(Error::other)
     }
 
+    #[inline]
     fn find_csrf_token_in_header(&self, req: &Request) -> Option<Vec<u8>> {
         req.headers()
             .get(&self.header_name)
@@ -253,12 +269,14 @@ impl CsrfHandler {
             .and_then(|v| base64::decode_config(v.as_bytes(), base64::URL_SAFE).ok())
     }
 
+    #[inline]
     fn find_csrf_token_in_query(&self, req: &Request) -> Option<Vec<u8>> {
         req.queries()
             .get(&self.query_param)
             .and_then(|v| base64::decode_config(v.as_bytes(), base64::URL_SAFE).ok())
     }
 
+    #[inline]
     async fn find_csrf_token_in_form(&self, req: &mut Request) -> Option<Vec<u8>> {
         req.form::<String>(&self.form_field)
             .await
@@ -327,6 +345,7 @@ impl Handler for CsrfHandler {
     }
 }
 
+#[inline]
 fn derive_key(secret: &[u8], key: &mut [u8; 32]) {
     let hk = hkdf::Hkdf::<sha2::Sha256>::new(None, secret);
     hk.expand(&[0u8; 0], key)
